@@ -1,4 +1,4 @@
-// Copyright 2013-2024 Daniel Parker
+// Copyright 2013-2025 Daniel Parker
 // Distributed under the Boost license, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
@@ -7,9 +7,18 @@
 #ifndef JSONCONS_JSON_FILTER_HPP
 #define JSONCONS_JSON_FILTER_HPP
 
+#include <cstddef>
+#include <cstdint>
 #include <string>
+#include <system_error>
 
+#include <jsoncons/config/compiler_support.hpp>
+#include <jsoncons/utility/byte_string.hpp>
+#include <jsoncons/json_exception.hpp>
 #include <jsoncons/json_visitor.hpp>
+#include <jsoncons/ser_context.hpp>
+#include <jsoncons/tag_type.hpp>
+#include <jsoncons/utility/unicode_traits.hpp>
 
 namespace jsoncons {
 
