@@ -1,4 +1,4 @@
-// Copyright 2013-2024 Daniel Parker
+// Copyright 2013-2025 Daniel Parker
 // Distributed under the Boost license, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
@@ -7,14 +7,14 @@
 #ifndef JSONCONS_JSON_OPTIONS_HPP
 #define JSONCONS_JSON_OPTIONS_HPP
 
+#include <cstdint>
 #include <cwchar>
 #include <functional>
-#include <limits> // std::numeric_limits
 #include <string>
+#include <system_error>
 
-#include <jsoncons/utility/extension_traits.hpp>
+#include <jsoncons/config/compiler_support.hpp>
 #include <jsoncons/json_error.hpp>
-#include <jsoncons/json_exception.hpp>
 #include <jsoncons/ser_context.hpp>
 
 namespace jsoncons {
