@@ -1,4 +1,4 @@
-// Copyright 2013-2024 Daniel Parker
+// Copyright 2013-2025 Daniel Parker
 // Distributed under the Boost license, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
@@ -8,12 +8,10 @@
 #define JSONCONS_SINK_HPP
 
 #include <cmath>
+#include <cstdint>
 #include <cstring> // std::memcpy
-#include <exception>
 #include <memory> // std::addressof
 #include <ostream>
-#include <stdexcept>
-#include <string>
 #include <vector>
 
 #include <jsoncons/config/jsoncons_config.hpp>
