@@ -1,4 +1,4 @@
-// Copyright 2013-2024 Daniel Parker
+// Copyright 2013-2025 Daniel Parker
 // Distributed under the Boost license, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
@@ -7,18 +7,19 @@
 #ifndef JSONCONS_SOURCE_HPP
 #define JSONCONS_SOURCE_HPP
 
+#include <cstdint>
 #include <cstring> // std::memcpy
 #include <exception>
 #include <functional>
 #include <istream>
 #include <iterator>
 #include <memory> // std::addressof
-#include <stdexcept>
 #include <string>
 #include <type_traits> // std::enable_if
 #include <vector>
 
-#include <jsoncons/byte_string.hpp> // jsoncons::byte_traits
+#include <jsoncons/config/compiler_support.hpp>
+#include <jsoncons/utility/byte_string.hpp> // jsoncons::byte_traits
 #include <jsoncons/config/jsoncons_config.hpp>
 #include <jsoncons/utility/extension_traits.hpp>
 
