@@ -1,4 +1,4 @@
-// Copyright 2013-2024 Daniel Parker
+// Copyright 2013-2025 Daniel Parker
 // Distributed under the Boost license, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
@@ -7,18 +7,29 @@
 #ifndef JSONCONS_EXT_CBOR_CBOR_ENCODER_HPP
 #define JSONCONS_EXT_CBOR_CBOR_ENCODER_HPP
 
+#include <cstddef>
+#include <cstdint>
+#include <cstring>
 #include <limits> // std::numeric_limits
+#include <map>
 #include <memory>
 #include <string>
+#include <system_error>
+#include <type_traits>
 #include <utility> // std::move
 #include <vector>
 
+#include <jsoncons/config/compiler_support.hpp>
 #include <jsoncons/config/jsoncons_config.hpp>
 #include <jsoncons/detail/parse_number.hpp>
 #include <jsoncons/json_exception.hpp> // jsoncons::ser_error
 #include <jsoncons/json_visitor.hpp>
+#include <jsoncons/ser_context.hpp>
 #include <jsoncons/sink.hpp>
+#include <jsoncons/tag_type.hpp>
 #include <jsoncons/utility/binary.hpp>
+#include <jsoncons/utility/unicode_traits.hpp>
+
 #include <jsoncons_ext/cbor/cbor_error.hpp>
 #include <jsoncons_ext/cbor/cbor_options.hpp>
 
@@ -376,7 +387,7 @@ private:
             else
             {
                 write_tag(25);
-                write_uint64_value(it->second);
+                write_uint64_value((*it).second);
             }
         }
         else
@@ -918,7 +929,7 @@ private:
             else
             {
                 write_tag(25);
-                write_uint64_value(it->second);
+                write_uint64_value((*it).second);
             }
         }
         else
@@ -948,7 +959,7 @@ private:
             else
             {
                 write_tag(25);
-                write_uint64_value(it->second);
+                write_uint64_value((*it).second);
             }
         }
         else
