@@ -1,4 +1,4 @@
-// Copyright 2013-2024 Daniel Parker
+// Copyright 2013-2025 Daniel Parker
 // Distributed under the Boost license, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
@@ -17,6 +17,7 @@
 #include <vector>
 
 #include <jsoncons/detail/write_number.hpp>
+#include <jsoncons/json_encoder.hpp>
 #include <jsoncons/json_exception.hpp>
 #include <jsoncons/json_visitor.hpp>
 #include <jsoncons/sink.hpp>
@@ -233,8 +234,8 @@ private:
                     auto it = buffered_line_.find(strings_buffer_[i]);
                     if (it != buffered_line_.end())
                     {
-                        sink_.append(it->second.data(),it->second.length());
-                        it->second.clear();
+                        sink_.append((*it).second.data(),(*it).second.length());
+                        (*it).second.clear();
                     }
                 }
                 sink_.append(options_.line_delimiter().data(), options_.line_delimiter().length());
@@ -392,11 +393,11 @@ private:
                     jsoncons::string_sink<std::basic_string<CharT>> bo(s);
                     write_null_value(bo);
                     bo.flush();
-                    if (!it->second.empty() && options_.subfield_delimiter() != char_type())
+                    if (!(*it).second.empty() && options_.subfield_delimiter() != char_type())
                     {
-                        it->second.push_back(options_.subfield_delimiter());
+                        (*it).second.push_back(options_.subfield_delimiter());
                     }
-                    it->second.append(s);
+                    (*it).second.append(s);
                 }
                 break;
             }
@@ -441,11 +442,11 @@ private:
                     jsoncons::string_sink<std::basic_string<CharT>> bo(s);
                     write_string_value(sv,bo);
                     bo.flush();
-                    if (!it->second.empty() && options_.subfield_delimiter() != char_type())
+                    if (!(*it).second.empty() && options_.subfield_delimiter() != char_type())
                     {
-                        it->second.push_back(options_.subfield_delimiter());
+                        (*it).second.push_back(options_.subfield_delimiter());
                     }
-                    it->second.append(s);
+                    (*it).second.append(s);
                 }
                 break;
             }
@@ -546,11 +547,11 @@ private:
                     jsoncons::string_sink<std::basic_string<CharT>> bo(s);
                     write_double_value(val, context, bo, ec);
                     bo.flush();
-                    if (!it->second.empty() && options_.subfield_delimiter() != char_type())
+                    if (!(*it).second.empty() && options_.subfield_delimiter() != char_type())
                     {
-                        it->second.push_back(options_.subfield_delimiter());
+                        (*it).second.push_back(options_.subfield_delimiter());
                     }
-                    it->second.append(s);
+                    (*it).second.append(s);
                 }
                 break;
             }
@@ -598,11 +599,11 @@ private:
                     jsoncons::string_sink<std::basic_string<CharT>> bo(s);
                     write_int64_value(val,bo);
                     bo.flush();
-                    if (!it->second.empty() && options_.subfield_delimiter() != char_type())
+                    if (!(*it).second.empty() && options_.subfield_delimiter() != char_type())
                     {
-                        it->second.push_back(options_.subfield_delimiter());
+                        (*it).second.push_back(options_.subfield_delimiter());
                     }
-                    it->second.append(s);
+                    (*it).second.append(s);
                 }
                 break;
             }
@@ -650,11 +651,11 @@ private:
                     jsoncons::string_sink<std::basic_string<CharT>> bo(s);
                     write_uint64_value(val, bo);
                     bo.flush();
-                    if (!it->second.empty() && options_.subfield_delimiter() != char_type())
+                    if (!(*it).second.empty() && options_.subfield_delimiter() != char_type())
                     {
-                        it->second.push_back(options_.subfield_delimiter());
+                        (*it).second.push_back(options_.subfield_delimiter());
                     }
-                    it->second.append(s);
+                    (*it).second.append(s);
                 }
                 break;
             }
@@ -699,11 +700,11 @@ private:
                     jsoncons::string_sink<std::basic_string<CharT>> bo(s);
                     write_bool_value(val,bo);
                     bo.flush();
-                    if (!it->second.empty() && options_.subfield_delimiter() != char_type())
+                    if (!(*it).second.empty() && options_.subfield_delimiter() != char_type())
                     {
-                        it->second.push_back(options_.subfield_delimiter());
+                        (*it).second.push_back(options_.subfield_delimiter());
                     }
-                    it->second.append(s);
+                    (*it).second.append(s);
                 }
                 break;
             }
