@@ -1,4 +1,4 @@
-// Copyright 2013-2024 Daniel Parker
+// Copyright 2013-2025 Daniel Parker
 // Distributed under the Boost license, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
@@ -7,17 +7,19 @@
 #ifndef JSONCONS_EXT_JSONPATH_JSONPATH_SELECTOR_HPP
 #define JSONCONS_EXT_JSONPATH_JSONPATH_SELECTOR_HPP
 
-#include <limits> // std::numeric_limits
+#include <cstddef>
+#include <cstdint>
 #include <memory>
-#include <regex>
 #include <string>
-#include <type_traits> // std::is_const
+#include <system_error>
 #include <utility> // std::move
 #include <vector>
 
-#include <jsoncons/json.hpp>
+#include <jsoncons/config/jsoncons_config.hpp>
+#include <jsoncons/tag_type.hpp>
+
 #include <jsoncons_ext/jsonpath/expression.hpp>
-#include <jsoncons_ext/jsonpath/jsonpath_error.hpp>
+#include <jsoncons_ext/jsonpath/path_node.hpp>
 
 namespace jsoncons { 
 namespace jsonpath {
@@ -260,7 +262,7 @@ namespace detail {
                 {
                     this->tail_select(context, root, 
                                         path_generator_type::generate(context, last, identifier_, options),
-                                        it->value(), receiver, options);
+                                        (*it).value(), receiver, options);
                 }
             }
             else if (current.is_array())
@@ -312,7 +314,7 @@ namespace detail {
                 {
                     return this->evaluate_tail(context, root, 
                                                path_generator_type::generate(context, last, identifier_, options),
-                                              it->value(), options, ec);
+                                              (*it).value(), options, ec);
                 }
                 return context.null_value();
             }
