@@ -1,4 +1,4 @@
-// Copyright 2013-2024 Daniel Parker
+// Copyright 2013-2025 Daniel Parker
 // Distributed under the Boost license, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
@@ -10,10 +10,12 @@
 #include <cassert>
 #include <iostream>
 #include <set>
-#include <sstream>
+#include <string>
+#include <unordered_map>
 
-#include <jsoncons/json.hpp>
+#include <jsoncons/config/compiler_support.hpp>
 #include <jsoncons/utility/uri.hpp>
+
 #include <jsoncons_ext/jsonpointer/jsonpointer.hpp>
 #include <jsoncons_ext/jsonschema/common/compilation_context.hpp>
 #include <jsoncons_ext/jsonschema/common/schema_builder.hpp>
@@ -165,7 +167,7 @@ namespace draft7 {
                         }
 
                         Json default_value{ jsoncons::null_type() };
-                        uri relative(it->value().template as<std::string>()); 
+                        uri relative((*it).value().template as<std::string>()); 
                         auto id = context.get_base_uri().resolve(relative);
                         validators.push_back(this->get_or_create_reference(sch, uri_wrapper{id}));
                         schema_validator_ptr = jsoncons::make_unique<object_schema_validator<Json>>(
@@ -209,7 +211,7 @@ namespace draft7 {
             auto it = sch.find("definitions");
             if (it != sch.object_range().end()) 
             {
-                for (const auto& def : it->value().object_range())
+                for (const auto& def : (*it).value().object_range())
                 {
                     std::string sub_keys[] = { "definitions", def.key() };
                     defs.emplace(def.key(), make_schema_validator(context, def.value(), sub_keys, anchor_dict));
@@ -219,7 +221,7 @@ namespace draft7 {
             it = sch.find("default");
             if (it != sch.object_range().end()) 
             {
-                default_value = it->value();
+                default_value = (*it).value();
             }
 
             for (const auto& key_value : sch.object_range())
@@ -227,7 +229,7 @@ namespace draft7 {
                 auto factory_it = keyword_factory_map_.find(key_value.key());
                 if (factory_it != keyword_factory_map_.end())
                 {
-                    auto validator = factory_it->second(context, key_value.value(), sch, anchor_dict);
+                    auto validator = (*factory_it).second(context, key_value.value(), sch, anchor_dict);
                     if (validator)
                     {   
                         validators.emplace_back(std::move(validator));
@@ -243,21 +245,21 @@ namespace draft7 {
             if (it != sch.object_range().end()) 
             {
                 std::string sub_keys[] = { "if" };
-                if_validator = make_schema_validator(context, it->value(), sub_keys, anchor_dict);
+                if_validator = make_schema_validator(context, (*it).value(), sub_keys, anchor_dict);
             }
 
             it = sch.find("then");
             if (it != sch.object_range().end()) 
             {
                 std::string sub_keys[] = { "then" };
-                then_validator = make_schema_validator(context, it->value(), sub_keys, anchor_dict);
+                then_validator = make_schema_validator(context, (*it).value(), sub_keys, anchor_dict);
             }
 
             it = sch.find("else");
             if (it != sch.object_range().end()) 
             {
                 std::string sub_keys[] = { "else" };
-                else_validator = make_schema_validator(context, it->value(), sub_keys, anchor_dict);
+                else_validator = make_schema_validator(context, (*it).value(), sub_keys, anchor_dict);
             }
             if (if_validator || then_validator || else_validator)
             {
@@ -270,7 +272,7 @@ namespace draft7 {
             it = sch.find("properties");
             if (it != sch.object_range().end()) 
             {
-                properties = this->make_properties_validator(context, it->value(), sch, anchor_dict);
+                properties = this->make_properties_validator(context, (*it).value(), sch, anchor_dict);
             }
             std::unique_ptr<pattern_properties_validator<Json>> pattern_properties;
 
@@ -278,14 +280,14 @@ namespace draft7 {
             it = sch.find("patternProperties");
             if (it != sch.object_range().end())
             {
-                pattern_properties = make_pattern_properties_validator(context, it->value(), sch, anchor_dict);
+                pattern_properties = make_pattern_properties_validator(context, (*it).value(), sch, anchor_dict);
             }
     #endif
 
             it = sch.find("additionalProperties");
             if (it != sch.object_range().end()) 
             {
-                validators.emplace_back(this->make_additional_properties_validator(context, it->value(), sch,
+                validators.emplace_back(this->make_additional_properties_validator(context, (*it).value(), sch,
                     std::move(properties), std::move(pattern_properties), anchor_dict));
             }
             else
@@ -306,14 +308,14 @@ namespace draft7 {
             if (it != sch.object_range().end()) 
             {
 
-                if (it->value().type() == json_type::array_value) 
+                if ((*it).value().type() == json_type::array_value) 
                 {
-                    validators.emplace_back(this->make_prefix_items_validator_07(context, it->value(), sch, anchor_dict));
+                    validators.emplace_back(this->make_prefix_items_validator_07(context, (*it).value(), sch, anchor_dict));
                 } 
-                else if (it->value().type() == json_type::object_value ||
-                           it->value().type() == json_type::bool_value)
+                else if ((*it).value().type() == json_type::object_value ||
+                           (*it).value().type() == json_type::bool_value)
                 {
-                    validators.emplace_back(this->make_items_validator("items", context, it->value(), sch, anchor_dict));
+                    validators.emplace_back(this->make_items_validator("items", context, (*it).value(), sch, anchor_dict));
                 }
             }
             return jsoncons::make_unique<object_schema_validator<Json>>(context.get_base_uri(), std::move(id),
@@ -372,7 +374,7 @@ namespace draft7 {
                 auto it = sch.find("$id"); // If $id is found, this schema can be referenced by the id
                 if (it != sch.object_range().end()) 
                 {
-                    uri relative(it->value().template as<std::string>()); 
+                    uri relative((*it).value().template as<std::string>()); 
                     auto resolved = parent.get_base_uri().resolve(relative);
                     id = resolved;
                     //std::cout << "$id: " << id << ", " << new_uri.string() << "\n";
