@@ -1,4 +1,4 @@
-// Copyright 2013-2024 Daniel Parker
+// Copyright 2013-2025 Daniel Parker
 // Distributed under the Boost license, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
@@ -7,6 +7,11 @@
 #ifndef JSONCONS_EXT_JSONSCHEMA_JSON_SCHEMA_FACTORY_HPP
 #define JSONCONS_EXT_JSONSCHEMA_JSON_SCHEMA_FACTORY_HPP
 
+#include <string>
+#include <unordered_map>
+
+#include <jsoncons/config/compiler_support.hpp>
+
 #include <jsoncons_ext/jsonschema/draft201909/schema_builder_201909.hpp>
 #include <jsoncons_ext/jsonschema/draft202012/schema_builder_202012.hpp>
 #include <jsoncons_ext/jsonschema/draft4/schema_builder_4.hpp>
@@ -38,11 +43,11 @@ namespace jsonschema {
                 auto it = sch.find("$schema");
                 if (it != sch.object_range().end())
                 { 
-                    builder = get_builder(std::move(sch), it->value().as_string_view(), options, schema_store_ptr, resolve_funcs, vocabulary);
+                    builder = get_builder(std::move(sch), (*it).value().as_string_view(), options, schema_store_ptr, resolve_funcs, vocabulary);
                     if (!builder)
                     {
                         std::string message("Unsupported schema version ");
-                        message.append(it->value().template as<std::string>());
+                        message.append((*it).value().template as<std::string>());
                         JSONCONS_THROW(schema_error(message));
                     }
                 }
@@ -155,7 +160,7 @@ namespace jsonschema {
                     auto vocab_it = meta_sch.find("$vocabulary");
                     if (vocab_it != meta_sch.object_range().end())
                     {
-                        const auto& vocab = vocab_it->value();
+                        const auto& vocab = (*vocab_it).value();
                         if (vocab.is_object())
                         {
                             for (const auto& member : vocab.object_range())
@@ -167,7 +172,7 @@ namespace jsonschema {
                     auto schema_it = meta_sch.find("$schema");
                     if (schema_it != meta_sch.object_range().end())
                     {
-                        builder = get_builder(std::move(sch), schema_it->value().as_string_view(), options, schema_store_ptr, resolve_funcs, vocabulary);
+                        builder = get_builder(std::move(sch), (*schema_it).value().as_string_view(), options, schema_store_ptr, resolve_funcs, vocabulary);
                         found = true;
                     }
                 }
