@@ -1,12 +1,15 @@
-// Copyright 2013-2024 Daniel Parker
+// Copyright 2013-2025 Daniel Parker
 // Distributed under Boost license
 
 #if defined(_MSC_VER)
 #include "windows.h" // test no inadvertant macro expansions
 #endif
-//#include <jsoncons_ext/csv/csv_options.hpp>
+
 #include <jsoncons_ext/csv/csv.hpp>
+
+#include <jsoncons/json.hpp>
 #include <jsoncons/json_reader.hpp>
+
 #include <sstream>
 #include <vector>
 #include <utility>
